@@ -1,10 +1,9 @@
 package LWP::ConnCache;
 
 use strict;
-use vars qw($DEBUG);
-
-our $VERSION = '6.18';
 
+our $VERSION = '6.19';
+our $DEBUG;
 
 sub new {
     my($class, %cnf) = @_;
