@@ -3,13 +3,11 @@ package LWP::Protocol::data;
 # Implements access to data:-URLs as specified in RFC 2397
 
 use strict;
-use vars qw(@ISA);
 
 require HTTP::Response;
 require HTTP::Status;
 
-require LWP::Protocol;
-@ISA = qw(LWP::Protocol);
+use base qw(LWP::Protocol);
 
 use HTTP::Date qw(time2str);
 require LWP;  # needs version number
@@ -21,20 +19,20 @@ sub request
     # check proxy
     if (defined $proxy)
     {
-	return HTTP::Response->new( &HTTP::Status::RC_BAD_REQUEST,
+	return HTTP::Response->new( HTTP::Status::RC_BAD_REQUEST,
 				  'You can not proxy with data');
     }
 
     # check method
     my $method = $request->method;
     unless ($method eq 'GET' || $method eq 'HEAD') {
-	return HTTP::Response->new( &HTTP::Status::RC_BAD_REQUEST,
+	return HTTP::Response->new( HTTP::Status::RC_BAD_REQUEST,
 				  'Library does not allow method ' .
 				  "$method for 'data:' URLs");
     }
 
     my $url = $request->uri;
-    my $response = HTTP::Response->new( &HTTP::Status::RC_OK, "Document follows");
+    my $response = HTTP::Response->new( HTTP::Status::RC_OK, "Document follows");
 
     my $media_type = $url->media_type;
 
