@@ -1,12 +1,13 @@
 package LWP::Simple;
 
 use strict;
-use vars qw($ua %loop_check $FULL_LWP @EXPORT @EXPORT_OK);
+
+our $VERSION = '6.19';
 
 require Exporter;
 
-@EXPORT = qw(get head getprint getstore mirror);
-@EXPORT_OK = qw($ua);
+our @EXPORT = qw(get head getprint getstore mirror);
+our @EXPORT_OK = qw($ua);
 
 # I really hate this.  It was a bad idea to do it in the first place.
 # Wonder how to get rid of it???  (It even makes LWP::Simple 7% slower
@@ -14,8 +15,6 @@ require Exporter;
 use HTTP::Status;
 push(@EXPORT, @HTTP::Status::EXPORT);
 
-our $VERSION = '6.18';
-
 sub import
 {
     my $pkg = shift;
@@ -24,13 +23,12 @@ sub import
 }
 
 use LWP::UserAgent ();
-use HTTP::Status ();
 use HTTP::Date ();
-$ua = LWP::UserAgent->new;  # we create a global UserAgent object
+
+our $ua = LWP::UserAgent->new;  # we create a global UserAgent object
 $ua->agent("LWP::Simple/$VERSION ");
 $ua->env_proxy;
 
-
 sub get ($)
 {
     my $response = $ua->get(shift);
